@@ -17,6 +17,6 @@ def cmd(ctx, url, key, secret, **kwargs):
     client = ctx.obj.start_client(url=url, key=key, secret=secret)
 
     with ctx.obj.exc_wrap(wraperror=ctx.obj.wraperror):
-        data = client.system.central_core.get()
+        data = client.central_core.get()
 
     click.secho(json_dump(data))
