@@ -170,6 +170,7 @@ class Formats(BaseEnum):
     connection_label = enum.auto()
     ip_preferred = enum.auto()
     os_distribution = "os-distribution"
+    dynamic_field = enum.auto()
 
 
 @dataclasses.dataclass
@@ -715,6 +716,12 @@ class OperatorTypeMaps(BaseData):
         itype = items.get("type")
         iformat = items.get("format")
 
+        if fformat == Formats.dynamic_field.value:
+            fformat = None
+
+        if iformat == Formats.dynamic_field.value:
+            iformat = None
+
         attrs = {
             "field_type": ftype,
             "field_format": fformat,
