@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
 """Parsers for API models."""
-from . import adapters, config, fields, system, tables, url_parser, wizards
+from . import adapters, config, fields, tables, url_parser, wizards
 
 __all__ = (
     "adapters",
     "config",
     "fields",
-    "system",
     "tables",
     "url_parser",
     "wizards",
