@@ -6,7 +6,11 @@ import pytest
 from axonius_api_client.exceptions import ApiError
 
 
-class CallbacksXlsx:
+class TestCallbacksXlsx:
+    @pytest.fixture(params=["api_devices", "api_users"])
+    def apiobj(self, request):
+        return request.getfixturevalue(request.param)
+
     @pytest.fixture(scope="class")
     def cbexport(self):
         return "xlsx"
@@ -30,15 +34,3 @@ class CallbacksXlsx:
     def test_fail_no_export_file(self, cbexport, apiobj, tmp_path):
         with pytest.raises(ApiError):
             apiobj.get(max_rows=1, export=cbexport)
-
-
-class TestDevicesCallbacksXlsx(CallbacksXlsx):
-    @pytest.fixture(scope="class")
-    def apiobj(self, api_devices):
-        return api_devices
-
-
-class TestUsersCallbacksXlsx(CallbacksXlsx):
-    @pytest.fixture(scope="class")
-    def apiobj(self, api_users):
-        return api_users
