@@ -2,6 +2,8 @@
 """Test suite for axonapi.api.assets."""
 import pytest
 
+from axonius_api_client.api import json_api
+
 
 class LabelsPrivate:
     def test_private_get(self, apiobj):
@@ -19,7 +21,8 @@ class LabelsPrivate:
 
         # add the label to the asset
         add_label_result = apiobj.labels._add(labels=labels, ids=[asset_id])
-        assert add_label_result == 1
+        assert isinstance(add_label_result, json_api.generic.IntValue)
+        assert add_label_result.value == 1
 
         # re-get the asset and check that it has the label
         assets_added = apiobj.get_by_values(values=labels, field="labels", fields="labels")
@@ -36,14 +39,16 @@ class LabelsPrivate:
         assert isinstance(all_labels_post_add, list)
 
         for label in all_labels_post_add:
-            assert isinstance(label, str)
+            assert isinstance(label, json_api.generic.StrValue)
+            assert label.value
 
         for label in labels:
-            assert label in all_labels_post_add
+            assert label in [x.value for x in all_labels_post_add]
 
         # remove the label from an asset
         remove_label_result = apiobj.labels._remove(labels=labels, ids=assets_added_ids)
-        assert remove_label_result >= 1
+        assert isinstance(remove_label_result, json_api.generic.IntValue)
+        assert remove_label_result.value >= 1
 
         # re-get the asset and check that it has the label
         assets_removed = apiobj.get_by_values(values=labels, field="labels", fields="labels")
@@ -54,7 +59,7 @@ class LabelsPrivate:
         assert isinstance(all_labels_post_remove, list)
 
         for label in labels:
-            assert label not in all_labels_post_remove
+            assert label not in [x.value for x in all_labels_post_remove]
 
 
 class LabelsPublic:
