@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 """Test suite."""
-from axonius_api_client.api.parsers.fields import schema_custom
+from axonius_api_client.parsers.fields import schema_custom
 
 
 def test_schema_custom():
