@@ -45,21 +45,22 @@ class TestConnect:
         assert "Connected" in repr(c)
 
         props = [
-            "users",
-            "devices",
+            "activity_logs",
             "adapters",
-            "instances",
             "dashboard",
+            "devices",
             "enforcements",
-            "run_action",
-            "central_core",
-            "system",
-            "system_users",
-            "system_roles",
+            "instances",
             "meta",
+            "remote_support",
             "settings_global",
             "settings_gui",
+            "settings_ip",
             "settings_lifecycle",
+            "signup",
+            "system_roles",
+            "system_users",
+            "users",
         ]
         for prop in props:
             prop_attr = getattr(c, prop)
